PoliBeePsync
============

This program synces a local folder with files uploaded by professors on the
 `BeeP <https://beep.metid.polimi.it>`_ platform.

This code is in the beta stage. Documentation is under construction
`here <http://www.davideolianas.com/polibeepsync/index.html>`_.